# ConsoleTetris
Tetris game in console

## Key Bindings
- `a` move left
- `d` move right
- `s` move down faster
- `space` rotate shape

### Special Thanks:
- Emre Soner Demir ([EmreSoner](https://github.com/EmreSoner))
